@@ -1,8 +1,50 @@
 /* For datatable view */
+
+var datatableview = {
+    make_xeditable: function(options) {
+        var options = $.extend({}, options);
+        if (!options.ajaxOptions) {
+            options.ajaxOptions = {}
+        }
+        if (!options.ajaxOptions.headers) {
+            options.ajaxOptions.headers = {}
+        }
+        options.ajaxOptions.headers['X-CSRFToken'] = datatableview.getCookie('csrftoken');
+        options.success = function (response, newValue) {
+            if (response.status == 'error') {
+                return response.msg;
+            }
+        }
+        return function(nRow, mData, iDisplayIndex) {
+            $('td a[data-xeditable]', nRow).editable(options);
+            return nRow;
+        }
+    },
+
+    getCookie: function(name) {
+        var cookieValue = null;
+        if (document.cookie && document.cookie != '') {
+            var cookies = document.cookie.split(';');
+            for (var i = 0; i < cookies.length; i++) {
+                var cookie = jQuery.trim(cookies[i]);
+                // Does this cookie string begin with the name we want?
+                if (cookie.substring(0, name.length + 1) == (name + '=')) {
+                    cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
+                    break;
+                }
+            }
+        }
+        return cookieValue;
+    }
+}
+
 $(function(){
-	if (!window.console) {
-		console = {log: function() {}};
-	}
+    if (typeof window.console === "undefined" || typeof window.console.log === "undefined") {
+        console = {
+            log: function(){},
+            info: function(){}
+        };
+    }
     var options_name_map = {
         'sortable': 'bSortable',
         'sorting': 'aaSorting',
